@@ -5,10 +5,12 @@
  *  Do all the initialization stuff.  For daemon mode, only
  *  children will return.
  *
- *  Time-stamp:      "2012-04-14 08:54:02 bkorb"
- *
+ * @addtogroup autogen
+ * @{
+ */
+/*
  *  This file is part of AutoGen.
- *  Copyright (c) 1992-2012 Bruce Korb - all rights reserved
+ *  Copyright (C) 1992-2013 Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -24,7 +26,12 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+static char const * ld_lib_path = NULL;
+
 /* = = = START-STATIC-FORWARD = = = */
+static void
+init_scm(void);
+
 static char const *
 make_quote_str(char const * str);
 
@@ -33,9 +40,6 @@ dep_usage(char const * fmt, ...);
 
 static void
 add_sys_env(char * env_name);
-
-static void
-add_env_vars(void);
 /* = = = END-STATIC-FORWARD = = = */
 
 #ifdef DAEMON_ENABLED
@@ -55,33 +59,20 @@ add_env_vars(void);
  * @param arg_vec the program name plus its arguments
  */
 LOCAL void
-initialize(int arg_ct, char** arg_vec)
+initialize(int arg_ct, char ** arg_vec)
 {
+    putenv(C(char *, ld_lib_path));
+
     ag_scribble_init();
 
     /*
      *  Initialize all the Scheme functions.
      */
     ag_init();
-    last_scm_cmd = SCHEME_INIT_TEXT;
-    ag_scm_c_eval_string_from_file_line(
-        SCHEME_INIT_TEXT, AG_TEXT_STRTABLE_FILE, SCHEME_INIT_TEXT_LINENO);
-
-    {
-#if GUILE_VERSION > 200000
-        static char const * const module = SCHEME_INIT_DEBUG_2_0;
-#else
-        static char const * const module = SCHEME_INIT_DEBUG_1_6;
-#endif
-        char * p = aprf(INIT_SCM_ERRS_FMT, module);
-        last_scm_cmd = p;
-        ag_scm_c_eval_string_from_file_line(p, __FILE__, __LINE__);
-        AGFREE(p);
-    }
+    init_scm();
 
     last_scm_cmd = NULL;
     processing_state = PROC_STATE_OPTIONS;
-    add_env_vars();
 
     process_ag_opts(arg_ct, arg_vec);
     exit_code = AUTOGEN_EXIT_LOAD_ERROR;
@@ -115,6 +106,47 @@ initialize(int arg_ct, char** arg_vec)
 #endif /* DAEMON_ENABLED */
 }
 
+static void
+init_scm(void)
+{
+    last_scm_cmd = SCHEME_INIT_TEXT;
+
+    {
+        SCM ini_res = ag_scm_c_eval_string_from_file_line(
+            SCHEME_INIT_TEXT, AG_TEXT_STRTABLE_FILE, SCHEME_INIT_TEXT_LINENO);
+        AGDUPSTR(libguile_ver, scm2display(ini_res), "ini res");
+    }
+
+    {
+        unsigned int maj, min, mic;
+        switch (sscanf(libguile_ver, "%u.%u.%u", &maj, &min, &mic)) {
+        case 2:
+        case 3: break;
+        default:
+            AG_ABEND(aprf(GUILE_VERSION_BAD, libguile_ver));
+            /* NOT_REACHED */
+        }
+        maj = min + (100 * maj);
+        if ((GUILE_VERSION / 1000) != maj)
+            AG_ABEND(aprf(GUILE_VERSION_WRONG, libguile_ver,
+                          MK_STR(GUILE_VERSION)));
+    }
+
+    {
+#       if GUILE_VERSION >= 200000
+#         define SCHEME_INIT_DEBUG SCHEME_INIT_DEBUG_2_0
+#       else
+#         define SCHEME_INIT_DEBUG SCHEME_INIT_DEBUG_1_6
+#       endif
+        char * p = aprf(INIT_SCM_ERRS_FMT, SCHEME_INIT_DEBUG);
+#       undef  SCHEME_INIT_DEBUG
+
+        last_scm_cmd = p;
+        ag_scm_c_eval_string_from_file_line(p, __FILE__, __LINE__);
+        AGFREE(p);
+    }
+}
+
 /**
  * make a name resilient to machinations made by 'make'.
  * Basically, dollar sign characters are doubled.
@@ -145,7 +177,7 @@ make_quote_str(char const * str)
 
         if (p == NULL)
             break;
-        sz = (p - str) + 1;
+        sz = (size_t)(p - str) + 1;
         memcpy(res, str, sz);
         res += sz;
         str += sz;
@@ -159,7 +191,7 @@ make_quote_str(char const * str)
 /**
  * Error in dependency specification
  *
- * @param fmt the error message format 
+ * @param fmt the error message format
  */
 static void
 dep_usage(char const * fmt, ...)
@@ -257,7 +289,7 @@ add_sys_env(char * env_name)
 
     for (;;) {
         if (IS_UPPER_CASE_CHAR(env_name[i]))
-            env_name[i] = tolower(env_name[i]);
+            env_name[i] = (char)tolower(env_name[i]);
         else if (! IS_ALPHANUMERIC_CHAR(env_name[i]))
             env_name[i] = '_';
 
@@ -270,7 +302,7 @@ add_sys_env(char * env_name)
      *  override it.
      */
     if (getenv(env_name) == NULL) {
-        char* pz;
+        char * pz;
 
         if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
             fprintf(trace_fp, TRACE_ADD_TO_ENV_FMT, env_name);
@@ -281,12 +313,42 @@ add_sys_env(char * env_name)
 }
 
 /**
- * Define system environment variables.  "__autogen__=1" is exported,
- * along with various ones derivable from Solaris sysinfo(3p) or uname.
+ * Prepare the raft of environment variables.
+ * This runs before Guile starts and grabs the value for LD_LIBRARY_PATH.
+ * Guile likes to fiddle that.  When we run initialize(), we will force it
+ * to match what we currently have.  Additionally, force our environment
+ * to be "C" and export all the variables that describe our system.
  */
-static void
-add_env_vars(void)
+LOCAL void
+prep_env(void)
 {
+    /*
+     *  as of 2.0.2, Guile will fiddle with strings all on its own accord.
+     *  Coerce the environment into being POSIX ASCII strings so it keeps
+     *  its bloody stinking nose out of our data.
+     */
+    putenv(C(char *, LC_ALL_IS_C));
+
+    /*
+     *  If GUILE_WARN_DEPRECATED has not been defined, then likely we are
+     *  not in a development environment and likely we don't want to give
+     *  our users any angst.
+     */
+    if (getenv(GUILE_WARN_DEP_STR) == NULL)
+        putenv(C(char *, GUILE_WARN_NO_ENV));
+
+    ld_lib_path = getenv(LD_LIB_PATH_STR);
+    if (ld_lib_path == NULL) {
+        ld_lib_path = LD_LIB_PATH_PFX;
+
+    } else {
+        size_t psz = strlen(ld_lib_path) + 1;
+        char * p = AGALOC(LD_LIB_PATH_PFX_LEN + psz, "lp");
+        memcpy(p, LD_LIB_PATH_PFX, LD_LIB_PATH_PFX_LEN);
+        memcpy(p + LD_LIB_PATH_PFX_LEN, ld_lib_path, psz);
+        ld_lib_path = p;
+    }
+
     /*
      *  Set the last resort search directories first (lowest priority)
      *  The lowest of the low is the config time install data dir.
@@ -492,7 +554,7 @@ spawnListens(char const * pzPort, sa_family_t addr_family)
         uint32_t p_len = strlen(pzPort);
 
         if (p_len > sizeof(sa.un_addr.sun_path))
-            AG_ABEND(aprf("AF_UNIX path exceeds %d", p_len));
+            AG_ABEND(aprf(PATH_TOO_BIG, p_len));
         sa.un_addr.sun_family  = AF_UNIX;
         strncpy(sa.un_addr.sun_path, pzPort, p_len);
         addr_len = sizeof(sa.un_addr) - sizeof(sa.un_addr.sun_path) + p_len;
@@ -513,7 +575,7 @@ spawnListens(char const * pzPort, sa_family_t addr_family)
 
         port = (uint16_t)strtol(pzPort, &pz, 0);
         if ((errno != 0) || (*pz != NUL))
-            AG_ABEND(aprf("Invalid port number:  '%s'", pzPort));
+            AG_ABEND(aprf(PORT_NUM_BAD, pzPort));
 
         sa.in_addr.sin_port = htons((short)port);
         addr_len = sizeof(sa.in_addr);
@@ -521,8 +583,7 @@ spawnListens(char const * pzPort, sa_family_t addr_family)
     break;
 
     default:
-        AG_ABEND(aprf("The '%d' address family cannot be handled",
-                      addr_family));
+        AG_ABEND(aprf(ADDR_FAMILY_BAD, addr_family));
     }
 
     if (bind(socket_fd, &sa.addr, addr_len) < 0) {
@@ -606,7 +667,6 @@ spawnListens(char const * pzPort, sa_family_t addr_family)
 daemonize(char const * pzStdin, char const * pzStdout, char const * pzStderr,
           char const * pzDaemonDir)
 {
-    static char const zNoFork[] = "Error %d while forking:  %s\n";
     /*
      *  Become a daemon process by exiting the current process
      *  and allowing the child to continue.  Also, change stdin,
@@ -618,7 +678,7 @@ daemonize(char const * pzStdin, char const * pzStdout, char const * pzStderr,
 
         switch (ret) {
         case -1:
-            fprintf(stderr, zNoFork, errno, strerror(errno));
+            fprintf(stderr, FORK_FAILED, errno, strerror(errno));
         default:
             exit(ret);
 
@@ -631,8 +691,7 @@ daemonize(char const * pzStdin, char const * pzStdout, char const * pzStderr,
      *  Now, become a process group and session group leader.
      */
     if (setsid() == -1) {
-        fprintf(stderr, "Error %d setting session ID:  %s\n",
-                errno, strerror(errno));
+        fprintf(stderr, SETSID_FAIL, errno, strerror(errno));
         exit(99);
     }
 
@@ -644,7 +703,7 @@ daemonize(char const * pzStdin, char const * pzStdout, char const * pzStderr,
      */
     switch (fork()) {
     case -1:
-        fprintf(stderr, zNoFork, errno, strerror(errno));
+        fprintf(stderr, FORK_FAILED, errno, strerror(errno));
         exit(99);
 
     case 0:
@@ -675,7 +734,9 @@ daemonize(char const * pzStdin, char const * pzStdout, char const * pzStderr,
     /* We are a daemon now */
 }
 #endif /* DAEMON_ENABLED */
-/*
+/**
+ * @}
+ *
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
