@@ -76,9 +76,9 @@
 # define AG_SCM_NULLP(_m)             scm_is_null(_m)
 # define AG_SCM_NUM_P(_n)             scm_is_number(_n)
 # define AG_SCM_PAIR_P(_p)            scm_is_true( scm_pair_p(_p))
-# define AG_SCM_STR02SCM(_s)          scm_from_utf8_string(_s)
-# define AG_SCM_STR2SCM(_st,_sz)      scm_from_utf8_stringn(_st,_sz)
-# define AG_SCM_TO_NEWSTR(_s)         scm_to_utf8_string(_s)
+# define AG_SCM_STR02SCM(_s)          scm_from_latin1_string(_s)
+# define AG_SCM_STR2SCM(_st,_sz)      scm_from_latin1_stringn(_st,_sz)
+# define AG_SCM_TO_NEWSTR(_s)         scm_to_latin1_string(_s)
 # define AG_SCM_STRING_P(_s)          scm_is_string(_s)
 # define AG_SCM_STRLEN(_s)            scm_c_string_length(_s)
 # define AG_SCM_SYM_P(_s)             scm_is_symbol(_s)
